@@ -23,10 +23,18 @@ sys.path.insert(0, os.path.abspath('../..'))
 extensions = [
     'sphinx.ext.autodoc',
     #'sphinx.ext.intersphinx',
-    'oslosphinx',
+    'openstackdocstheme',
     'oslo_config.sphinxext',
 ]
 
+# openstackdocstheme options
+repository_name = 'openstack/oslo.reports'
+bug_project = 'oslo.reports'
+bug_tag = ''
+
+# Must set this variable to include year, month, day, hours, and minutes.
+html_last_updated_fmt = '%Y-%m-%d %H:%M'
+
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
 # execute "export SPHINX_DEBUG=1" in your terminal to disable
@@ -61,6 +69,8 @@ modindex_common_prefix = ['oslo_reports.']
 # html_theme_path = ["."]
 # html_theme = '_theme'
 # html_static_path = ['static']
+html_theme = 'openstackdocs'
+
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
